Version 1.1.0
-------------

2019-07-15

New major features
..................

* Add functions to make viewers directly from Neo objects
  (:pr:`8`, :pr:`20`)

* Add CsvEpochSource and many EpochEncoder enhancements
  (:pr:`13`, :pr:`27`, :pr:`60`)

* Add keyboard shortcuts for navigation
  (:pr:`18`, :pr:`25`, :pr:`41`)

* Add time zoom to most viewers, add global time zoom option
  (:pr:`17`)

Aesthetics
..........

* Standardize opacity, color, and z-order for vline marking current time for all viewers
  (:pr:`14`)

* Improve label legibility
  (:pr:`19`)

* Add ``scatter_size`` as an adjustable parameter to TraceViewer
  (:pr:`21`)

* Remove "s" suffixes from navigation spinboxes for time and xsize
  (:pr:`24`)

* Add line-width option to TraceViewer
  (:pr:`26`, :pr:`43`)

* Allow user to change vline color
  (:pr:`45`)

* Add param for setting background fill color of channel labels
  (:pr:`49`)

* Use same color determination for EpochEncoder rectangles as EpochViewer
  (:pr:`50`)

Zoom fixes
..........

* Fix time zoom rate
  (:pr:`23`)

* Fix signal offsets when zooming in TraceViewer
  (:pr:`48`)

Plot fixes
..........

* Fix time alignment across viewers by removing x-padding
  (:pr:`7`)

* Fix poor plotting precision at long times
  (:pr:`28`, :pr:`29`)

* Fix for drawing epochs that end exactly at ``t_stop``
  (:pr:`39`)

* Fix TraceViewer drawing incomplete curves when zoomed in
  (:pr:`47`)

* Appropriately rescale raw signals in AnalogSignalFromNeoRawIOSource
  (:pr:`44`, :pr:`56`, :pr:`57`)

* Fix trace label and baseline placement for RawIOs with non-zero offset
  (:pr:`58`, :pr:`61`)

* Fix crash when scatter plot channels are hidden
  (:pr:`64`)

Video fixes
...........

* VideoViewer performance fixes
  (:pr:`10`, :pr:`11`)

* Fix for video streams lacking ``start_time``
  (:pr:`30`)

* Address PyAV deprecation warnings
  (:pr:`31`)

* Fix for seeking non-existent video frames before start and beyond end of video
  (:pr:`33`, :pr:`36`)

* Ensure ``time_to_frame_index`` always returns the frame preceding t
  (:pr:`35`)

* Clear video image when t is before the start or after the end of video
  (:pr:`37`)

Other bug fixes
...............

* Fix missing icons for play and stop buttons
  (:pr:`15`, :pr:`46`)

* Fix errors when dragging or scrolling mouse on viewer axes
  (:pr:`51`, :pr:`52`)

* Fix clicking on current selection in EventList, EpochEncoder table, and DataFrameView
  (:pr:`54`, :pr:`55`)

* Fix for standalone app crash when signals start after t=2.1
  (:pr:`38`)

* Catch ``make_video_file`` crash
  (:pr:`59`)

* 2 bug fixes
  (:pr:`22`)

* Some bug fixes
  (:pr:`9`)

* Hide debug statements
  (:pr:`32`)

Documentation
.............

* Add epoch encoder example
  (:pr:`12`)

* Update docs and README
  (:pr:`62`)
